import { IHeaderContent } from "./doc/IHeaderContent";
/**
 * Class to contain default z/OSMF headers
 * @export
 * @class ZosmfHeaders
 */
export declare class ZosmfHeaders {
    /**
     * lrecl header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_INTRDR_LRECL = "X-IBM-Intrdr-Lrecl";
    /**
     * recfm header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_INTRDR_RECFM = "X-IBM-Intrdr-Recfm";
    /**
     * job class header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_INTRDR_CLASS_A: IHeaderContent;
    /**
     * fixed recfm header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_INTRDR_RECFM_F: IHeaderContent;
    /**
     * 80 lrecl header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_INTRDR_LRECL_80: IHeaderContent;
    /**
     * 256 lrecl header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_INTRDR_LRECL_256: IHeaderContent;
    /**
     * text type header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_INTRDR_MODE_TEXT: IHeaderContent;
    /**
     * n/a header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_NOTIFICATION_URL: IHeaderContent;
    /**
     * base header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_ATTRIBUTES_BASE: IHeaderContent;
    /**
     * If you use this header, delete job API will be asynchronous.
     * This is the default setting, so using this header is not really necessary unless you want to be explicit.
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_JOB_MODIFY_VERSION_1: IHeaderContent;
    /**
     * If you use this header, delete job API will be synchronous.
     * But using it may cause problems for some users depending on their maintenance level and configuration.
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_JOB_MODIFY_VERSION_2: IHeaderContent;
    /**
     * security header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_CSRF_ZOSMF_HEADER: object;
    /**
     * binary transfer header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_BINARY: IHeaderContent;
    /**
     * binary by record header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_BINARY_BY_RECORD: IHeaderContent;
    /**
     * text transfer header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_TEXT: IHeaderContent;
    /**
     * octet stream header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly OCTET_STREAM: IHeaderContent;
    /**
     * plain text header
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly TEXT_PLAIN: IHeaderContent;
    /**
     * This header value specifies the maximum number of items to return.
     * To request that all items be returned, set this header to 0. If you omit this header, or specify an incorrect value,
     * up to 1000 items are returned by default.
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_MAX_ITEMS: IHeaderContent;
    /**
     * data set migrated recall headers
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_MIGRATED_RECALL_WAIT: IHeaderContent;
    static readonly X_IBM_MIGRATED_RECALL_NO_WAIT: IHeaderContent;
    static readonly X_IBM_MIGRATED_RECALL_ERROR: IHeaderContent;
    /**
     * Header to check ETag on read
     * Request returns HTTP 304 if not modified
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly IF_NONE_MATCH = "If-None-Match";
    /**
     * Header to check ETag on write
     * Request returns HTTP 412 if not matched
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly IF_MATCH = "If-Match";
    /**
     * Header to force return of ETag in response regardless of file size
     * By default Etag is returned only for files smaller than a system determined value (which is at least 8mb)
     * @static
     * @memberof ZosmfHeaders
     */
    static readonly X_IBM_RETURN_ETAG: IHeaderContent;
}
